package com.zd.laboratory.service;

import java.util.List;
import java.util.Map;

import com.zd.laboratory.domain.LabCheckOption;
import com.zd.laboratory.domain.vo.LabCheckOptionStatisticsVo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 检查项选项Service接口
 *
 * @author liubo
 * @date 2021-12-30
 */
public interface ILabCheckOptionService {
    /**
     * 查询检查项选项
     *
     * @param id 检查项选项主键
     * @return 检查项选项
     */
    public LabCheckOption selectLabCheckOptionById(Long id);

    /**
     * 查询检查项选项列表
     *
     * @param labCheckOption 检查项选项
     * @return 检查项选项集合
     */
    public List<LabCheckOption> selectLabCheckOptionList(LabCheckOption labCheckOption);

    /**
     * 新增检查项选项
     *
     * @param labCheckOption 检查项选项
     * @return 结果
     */
    public LabCheckOption insertLabCheckOption(LabCheckOption labCheckOption);

    /**
     * 修改检查项选项
     *
     * @param labCheckOption 检查项选项
     * @return 结果
     */
    public int updateLabCheckOption(LabCheckOption labCheckOption);

    /**
     * 批量删除检查项选项
     *
     * @param ids 需要删除的检查项选项主键集合
     * @return 结果
     */
    public int deleteLabCheckOptionByIds(Long[] ids);

    /**
     * 删除检查项选项信息
     *
     * @param id 检查项选项主键
     * @return 结果
     */
    public int deleteLabCheckOptionById(Long id);

    void importData(MultipartFile file);

    List<LabCheckOption> selectLabCheckOptionTempList(LabCheckOption labCheckOption);

    public void getParentNames(LabCheckOption option, Long parentId, String parentNames);

    Map<String, Object> queryCheckOptionStatistics(LabCheckOptionStatisticsVo labCheckOptionStatisticsVo);

    List<LabCheckOptionStatisticsVo> queryCheckOptionStatisticDtails(LabCheckOptionStatisticsVo labCheckOptionStatisticsVo);
}
